﻿using Infragistics.Controls.Charts;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.Loaded += MainWindow_Loaded;
        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            var data = this.DataContext as CarProduction;
            
            
            var group = data.cars.GroupBy(x => x.Name);

            foreach (var item in group)
            {
                //Make Level
                var makes = item.ToList();

                var models = makes.First() as Make;

                CategoryDateTimeXAxis dt = new CategoryDateTimeXAxis();
                dt.ItemsSource = models.model;
                dt.DateTimeMemberPath = "ManufacturingDate";
                dt.Label = "{ManufacturingDate}";
                dt.MinimumValue = DateTime.Now.AddDays(-5);
                dt.MaximumValue = DateTime.Now.AddDays(30);
                AxisLabelSettings settings = new AxisLabelSettings();
                dt.LabelSettings = settings;
                
                settings.Visibility = Visibility.Collapsed;
                this.DataChart.Axes.Add(dt);

                SplineSeries sp = new SplineSeries();
                sp.ItemsSource = models.model;
                sp.ValueMemberPath = "Price";
                sp.XAxis = dt;
                sp.YAxis = YAxis;
                DataChart.Series.Add(sp);
                sp.MarkerType = MarkerType.Circle;
            }
        }
    }

    public class Make 
    {
        public int Index { get; set; }
       
        public string Name { get; set; }
        public ObservableCollection<CARmodel> model { get; set; }

    }

    public class CARmodel : ObservableCollection<Make>
    {
        public DateTime ManufacturingDate { get; set; }
        public Make Make { get; set; }
        public double Price { get; set; }
        public string Model { get; set; }
    }

    public class CarProduction : ObservableCollection<Make>
    {
        private ObservableCollection<Make> _Cars;
        //TODO create two different lists (eg. Honda, Mazda)

        private ObservableCollection<CARmodel> _Models;
        public CarProduction()
        {


            cars = new ObservableCollection<Make>
            {
                new Make()
                {
                   
                    Index = 0,
                   
                    Name = "Honda",
                    model = new ObservableCollection<CARmodel>()
                    
                },
                                
                new Make()
                {
                   
                    Index = 1,

                    Name = "Mazda",
                    model = new ObservableCollection<CARmodel>()
                }

                

            };
            //this.Add(_Cars[0]);
            //this.Add(_Cars[1]);

            models = new ObservableCollection<CARmodel>
            {
                new CARmodel()
                {
                     ManufacturingDate = DateTime.Now,
                    Price = 40000,
                    Model = "Civic",
                    Make = cars[0]             
                },
                new CARmodel()
                {
                     ManufacturingDate = DateTime.Today.AddDays(10),
                    Price = 40000,
                    Model = "Accord",
                    Make = cars[0]
                },

                 new CARmodel()
                {
                     ManufacturingDate = DateTime.Today.AddDays(10),
                    Price = 60000,
                    Model = "Mazda 3",
                    Make = cars[1]
                }
            };


            _Cars[0].model.Add(_Models[0]);
            _Cars[0].model.Add(_Models[1]);
            _Cars[1].model.Add(_Models[2]);

        }

        public ObservableCollection<Make> cars
        {
            get { return _Cars; }
            set { _Cars = value; }
        }
        public ObservableCollection<CARmodel> models
        {
            get { return _Models; }
            set { _Models = value; }
        }

    }

}
